/* This file is part of the Springlobby (GPL v2 or later), see COPYING */

#ifndef SPRINGLOBBY_HEADERGUARD_HOSTBATTLEDIALOG_PUBLIC_H
#define SPRINGLOBBY_HEADERGUARD_HOSTBATTLEDIALOG_PUBLIC_H

class wxWindow;
namespace SL
{
//! this shows an instance and handles everything wrt data feeding and input handling
void RunHostBattleDialog(wxWindow* parent);
}

#endif // SPRINGLOBBY_HEADERGUARD_HOSTBATTLEDIALOG_PUBLIC_H
